@@ -6,7 +6,8 @@ import PropertyLengthMeasure from '../../../../catalog/properties/property-lengh
 function HoleAttributesEditor(_ref, _ref2) {
   var element = _ref.element,
       _onUpdate = _ref.onUpdate,
-      attributeFormData = _ref.attributeFormData;
+      attributeFormData = _ref.attributeFormData,
+      state = _ref.state;
   var translator = _ref2.translator;
 
   var offsetA = attributeFormData.has('offsetA') ? attributeFormData.get('offsetA') : element.offsetA;
@@ -20,14 +21,16 @@ function HoleAttributesEditor(_ref, _ref2) {
       onUpdate: function onUpdate(mapped) {
         return _onUpdate('offsetA', mapped);
       },
-      configs: { label: 'Offset 1', min: 0, max: Infinity }
+      configs: { label: 'Offset 1', min: 0, max: Infinity },
+      state: state
     }),
     React.createElement(PropertyLengthMeasure, {
       value: offsetB,
       onUpdate: function onUpdate(mapped) {
         return _onUpdate('offsetB', mapped);
       },
-      configs: { label: 'Offset 2', min: 0, max: Infinity }
+      configs: { label: 'Offset 2', min: 0, max: Infinity },
+      state: state
     })
   );
 }
@@ -35,7 +38,8 @@ function HoleAttributesEditor(_ref, _ref2) {
 HoleAttributesEditor.propTypes = {
   element: PropTypes.object.isRequired,
   onUpdate: PropTypes.func.isRequired,
-  attributeFormData: PropTypes.object.isRequired
+  attributeFormData: PropTypes.object.isRequired,
+  state: PropTypes.object.isRequired
 };
 
 HoleAttributesEditor.contextTypes = {
