@@ -225,6 +225,10 @@ var Scene3DViewer = function (_React$Component) {
           camera.updateMatrix();
           camera.updateMatrixWorld();
 
+          for (var elemID in planData.sceneGraph.LODs) {
+            planData.sceneGraph.LODs[elemID].update(camera);
+          }
+
           _this2.renderer.render(scene3D, camera);
           requestAnimationFrame(render);
         }
