@@ -70,7 +70,6 @@ export var END_DRAGGING_VERTEX = 'END_DRAGGING_VERTEX';
 export var SET_LAYER_PROPERTIES = 'SET_LAYER_PROPERTIES';
 export var ADD_LAYER = 'ADD_LAYER';
 export var SELECT_LAYER = 'SELECT_LAYER';
-export var OPEN_LAYER_CONFIGURATOR = 'OPEN_LAYER_CONFIGURATOR';
 export var REMOVE_LAYER = 'REMOVE_LAYER';
 
 //GROUPING ACTIONS
@@ -147,7 +146,6 @@ export var SCENE_ACTIONS = {
   ADD_LAYER: ADD_LAYER,
   SET_LAYER_PROPERTIES: SET_LAYER_PROPERTIES,
   SELECT_LAYER: SELECT_LAYER,
-  OPEN_LAYER_CONFIGURATOR: OPEN_LAYER_CONFIGURATOR,
   REMOVE_LAYER: REMOVE_LAYER
 };
 
@@ -177,7 +175,6 @@ export var MODE_UPLOADING_IMAGE = 'MODE_UPLOADING_IMAGE';
 export var MODE_FITTING_IMAGE = 'MODE_FITTING_IMAGE';
 export var MODE_VIEWING_CATALOG = 'MODE_VIEWING_CATALOG';
 export var MODE_CONFIGURING_PROJECT = 'MODE_CONFIGURING_PROJECT';
-export var MODE_CONFIGURING_LAYER = 'MODE_CONFIGURING_LAYER';
 
 //UNITS
 export var UNIT_MILLIMETER = 'mm';
