@@ -1,4 +1,5 @@
-import React, {PropTypes} from 'react';
+import React from 'react';
+import PropTypes from 'prop-types';
 import CatalogItem from './catalog-item';
 import {Seq} from 'immutable'
 import ContentContainer from '../style/content-container';
