@@ -102,6 +102,11 @@ export default function Viewer2D({state, width, height},
 
   let onMouseMove = viewerEvent => {
     let event = viewerEvent.originalEvent;
+
+    var evt = new Event('mousemove-planner-event' );
+    evt.viewerEvent = viewerEvent;
+    document.dispatchEvent(evt);
+
     event.preventDefault();
     let {x, y} = mapCursorPosition(viewerEvent);
 
@@ -149,44 +154,55 @@ export default function Viewer2D({state, width, height},
 
   let onMouseDown = viewerEvent => {
     let event = viewerEvent.originalEvent;
+
+    var evt = new Event('mousedown-planner-event' );
+    evt.viewerEvent = viewerEvent;
+    document.dispatchEvent(evt);
+
     event.preventDefault();
     let {x, y} = mapCursorPosition(viewerEvent);
 
-    switch (mode) {
-      case constants.MODE_IDLE:
+    if( mode === constants.MODE_IDLE )
+    {
+      let elementData = extractElementData(event.target);
+      if ( !elementData || !elementData.selected ) return;
 
-        let elementData = extractElementData(event.target);
-        if (!(elementData && elementData.selected)) return;
+      switch ( elementData.prototype ) {
+        case 'lines':
+          linesActions.beginDraggingLine(elementData.layer, elementData.id, x, y, !event.getModifierState("Alt"));
+          event.stopPropagation();
+          break;
 
-        switch (elementData ? elementData.prototype : 'none') {
-          case 'lines':
-            linesActions.beginDraggingLine(elementData.layer, elementData.id, x, y, !event.getModifierState("Alt"));
-            event.stopPropagation();
-            break;
+        case 'vertices':
+          verticesActions.beginDraggingVertex(elementData.layer, elementData.id, x, y, !event.getModifierState("Alt"));
+          event.stopPropagation();
+          break;
 
-          case 'vertices':
-            verticesActions.beginDraggingVertex(elementData.layer, elementData.id, x, y, !event.getModifierState("Alt"));
-            event.stopPropagation();
-            break;
+        case 'items':
+          if (elementData.part === 'rotation-anchor')
+            itemsActions.beginRotatingItem(elementData.layer, elementData.id, x, y);
+          else
+            itemsActions.beginDraggingItem(elementData.layer, elementData.id, x, y);
+          event.stopPropagation();
+          break;
 
-          case 'items':
-            if (elementData.part === 'rotation-anchor')
-              itemsActions.beginRotatingItem(elementData.layer, elementData.id, x, y);
-            else
-              itemsActions.beginDraggingItem(elementData.layer, elementData.id, x, y);
-            event.stopPropagation();
-            break;
+        case 'holes':
+          holesActions.beginDraggingHole(elementData.layer, elementData.id, x, y);
+          event.stopPropagation();
+          break;
 
-          case 'holes':
-            holesActions.beginDraggingHole(elementData.layer, elementData.id, x, y);
-            event.stopPropagation();
-            break;
-        }
+        default: break;
+      }
     }
   };
 
   let onMouseUp = viewerEvent => {
     let event = viewerEvent.originalEvent;
+
+    var evt = new Event('mouseup-planner-event' );
+    evt.viewerEvent = viewerEvent;
+    document.dispatchEvent(evt);
+
     event.preventDefault();
     let {x, y} = mapCursorPosition(viewerEvent);
 
@@ -214,6 +230,7 @@ export default function Viewer2D({state, width, height},
             break;
 
           case 'items':
+            //console.log( 'AAA', event, elementData );
             itemsActions.selectItem(elementData.layer, elementData.id);
             event.stopPropagation();
             break;
